@@ -172,14 +172,23 @@ class WorkflowCollectionEngagementDetailsView(APIView):
             )
             data = serializer.data
             data["state"] = engagement_serializer.data["state"]
+
             # Check if we are able to proceed to the next step
             if data["user_responses"] and "inputs" in data["user_responses"][-1].keys():
-                checker = [
-                    entry["is_valid"] for entry in data["user_responses"][-1]["inputs"]
-                ]
-                data["proceed"] = False if False in checker else True
+
+                are_answers_valid = []
+
+                for entry in serializer.data["user_responses"][-1]["inputs"]:
+                    try:
+                        are_answers_valid.append(entry["is_valid"])
+                    except KeyError as exception:
+                        print("Exception Encountered: ", exception)
+                        print("Entry: ", entry)
+
+                data["state"]["proceed"] = False if False in are_answers_valid else True
             else:
-                data["proceed"] = True
+                data["state"]["proceed"] = True
+
             return Response(data=data, status=status.HTTP_201_CREATED)
 
 
@@ -309,8 +318,7 @@ class WorkflowCollectionEngagementDetailView(APIView):
             workflow_collection_engagement__user=request.user,
         )
 
-        # If "users_responses" exists in the payload and is not a false-like value
-        # add a submittedTime attribute to it. TODO: This perhaps should be done on the front-end.
+        # We need to set a submitted time on the input
         if "user_responses" in request.data.keys() and request.data["user_responses"]:
             request.data["user_responses"][-1]["submittedTime"] = str(timezone.now())
 
@@ -352,11 +360,17 @@ class WorkflowCollectionEngagementDetailView(APIView):
 
             # Check if we are able to proceed to the next step
             if data["user_responses"] and "inputs" in data["user_responses"][-1].keys():
-                checker = [
-                    entry["is_valid"]
-                    for entry in serializer.data["user_responses"][-1]["inputs"]
-                ]
-                data["state"]["proceed"] = False if False in checker else True
+
+                are_answers_valid = []
+
+                for entry in serializer.data["user_responses"][-1]["inputs"]:
+                    try:
+                        are_answers_valid.append(entry["is_valid"])
+                    except KeyError as exception:
+                        print("Exception Encountered: ", exception)
+                        print("Entry: ", entry)
+
+                data["state"]["proceed"] = False if False in are_answers_valid else True
             else:
                 data["state"]["proceed"] = True
 
